@@ -12,8 +12,8 @@ sub ACTION_build {
 	my %notes = $self->notes;
 	my $path_types = $notes{'path_types'};
 	
-	my $config_fh      = IO::Any->read(['default', 'SysPathConfig.pm']);
-	my $blib_config_fh = IO::Any->write([$self->blib, 'lib', 'SysPathConfig.pm']);
+	my $config_fh      = IO::Any->read(['default', 'SPc.pm']);
+	my $blib_config_fh = IO::Any->write([$self->blib, 'lib', 'SPc.pm']);
 	while (my $line = <$config_fh>) {
 		if ($line =~ m/^sub \s+ ($path_types) \s* {/xms) {
 			$line = 'sub '.$1." {'".$notes{$1}."'};"."\n"
